"""Router for token validation."""

from typing import Annotated

from ab_core.dependency import Depends
from ab_core.token_validator.schema.validated_token import ValidatedOIDCClaims
from ab_core.token_validator.token_validators import TokenValidator
from fastapi import APIRouter

from ..schema import ValidateTokenRequest

router = APIRouter(
    prefix="/validate",
    tags=["Token Validator"],
)


@router.post(
    "",
    response_model=ValidatedOIDCClaims,
)
async def validate_token(
    request: ValidateTokenRequest,
    token_validator: Annotated[TokenValidator, Depends(TokenValidator, persist=True)],
):
    """Validate a token."""
    return await token_validator.validate(request.token)



"""Main application for the token validator service."""

from fastapi import FastAPI, Request
from fastapi.responses import JSONResponse
from jose import ExpiredSignatureError, JWTError

from ab_service.token_validator.routes.validate import router as validate_router

app = FastAPI()
app.include_router(validate_router)


@app.exception_handler(ExpiredSignatureError)
async def expired_signature_handler(_request: Request, _exc: ExpiredSignatureError):
    """Handle expired token errors."""
    return JSONResponse(
        status_code=401,
        content={"detail": "Token expired"},
    )


@app.exception_handler(JWTError)
async def jwt_error_handler(_request: Request, exc: JWTError):
    """Handle generic JWT errors."""
    return JSONResponse(
        status_code=401,
        content={"detail": f"Token validation failed: {exc}"},
    )
